@@ -79,7 +79,7 @@ def create_image(list_comp_data,path_img, t=0):
     arr_comps = []
     for comp_data in list_comp_data:
         comp_data["job_id"] = 1
-        comp_data["mf_server"] = ""
+        comp_data["mf_server"] = "http://api-magicframe.automusic.win/"
         if comp_data['type'] == "compilation" or comp_data['type'] == "lyric" :
             continue
         arr_comps.append(Component.convert(comp_data).make())
@@ -588,7 +588,7 @@ class LyricComp(Component):
         self.fade_in = json_data['fade_in']
         self.fade_out = json_data['fade_out']
         self.is_lyric_outro=False
-        self.is_lyric_outro=False
+        self.is_outro_claim=False
         self.outro_claim_topic =None
         if "is_lyric_outro" in json_data:
             self.is_lyric_outro = json_data['is_lyric_outro']
